@@ -189,7 +189,7 @@ def get_tty_size():
     return int(rows), int(columns)
 
 
-def real_height(buf, pixels_per_line=24):
+def real_height(buf, pixels_per_line=int(qs_config.basicSelect("terminal_font_size"))):
     im_width, im_height = get_image_shape(buf)
     if im_height:
         assert pixels_per_line > 0
@@ -346,24 +346,56 @@ def image_preview(
 
         buf = to_content_buf(img)
         width, height = get_image_shape(buf)
-        _real_height = real_height(buf)
-        _real_width = math.ceil(width / height * _real_height) * 2 + 1
+        rate = width / height
+        font_rate = 2.125
+        _real_height = height / int(qs_config.basicSelect("terminal_font_size"))
+        _real_width = (
+            width * font_rate / int(qs_config.basicSelect("terminal_font_size"))
+        )
 
         console_width = (
             qs_console_width if not set_width_in_rc_file else set_width_in_rc_file
         )
-        center_prefix = (eval(qs_config.basicSelect("center_prefix")))(console_width)
+
+        console_height = qs_default_console.height - 3
+
+        if _real_width > console_width:
+            _real_width = console_width
+            _real_height = math.floor(_real_width / rate / font_rate)
+
+            max_iter = 100
+            _iter = 0
+            while math.fabs(_real_width / _real_height / font_rate - rate) > 0.01:
+                _real_height += (
+                    1 if _real_width / _real_height / font_rate > rate else -1
+                )
+                _iter += 1
+                if _real_height <= 1 or _iter > max_iter:
+                    break
+            if height > width:
+                _real_height += 1
+        if _real_height > console_height:
+            _real_height = console_height
+            _real_width = math.floor(_real_height * rate * font_rate)
+
+            max_iter = 100
+            _iter = 0
+            while math.fabs(_real_width / _real_height / font_rate - rate) > 0.01:
+                _real_width += (
+                    -1 if _real_width / _real_height / font_rate > rate else 1
+                )
+                _iter += 1
+                if _real_width <= 1 or _iter > max_iter:
+                    break
+            if height < width:
+                _real_width += 1
+
         qs_default_console.print(
-            " "
-            * int(
-                max((console_width - _real_width) / 2 - 1, 0)
-                if not center_prefix
-                else center_prefix
-            ),
+            " " * max((console_width - _real_width) // 2, 0),
             end="",
         )
 
-        imgcat(buf, height=real_height(buf))
+        imgcat(buf, width=min(_real_width, console_width), height=_real_height)
     except Exception as e:
         if qs_console_status:
             qs_console_status.stop()
